<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Zoom</name>
    <message>
        <location filename="../Zoom.js" line="+51"/>
        <source>Zoom</source>
        <translation>Przybliżanie</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Zoom Tools</source>
        <translation>Narzędzia przybliżania</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show zoom tools</source>
        <translation>Wyświetla narzędzia przybliżania</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Zoom</source>
        <translation>&amp;Przybliż</translation>
    </message>
</context>
</TS>
